@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'ruby2_keywords'
 require 'mocha/method_matcher'
 require 'mocha/parameters_matcher'
@@ -6,23 +8,22 @@ require 'mocha/return_values'
 require 'mocha/exception_raiser'
 require 'mocha/thrower'
 require 'mocha/yield_parameters'
-require 'mocha/is_a'
 require 'mocha/in_state_ordering_constraint'
 require 'mocha/change_state_side_effect'
 require 'mocha/cardinality'
 require 'mocha/configuration'
-require 'mocha/block_matcher'
+require 'mocha/block_matchers'
 require 'mocha/backtrace_filter'
 
 module Mocha
   # Methods on expectations returned from {Mock#expects}, {Mock#stubs}, {ObjectMethods#expects} and {ObjectMethods#stubs}.
   class Expectation
-    # Modifies expectation so that the number of calls to the expected method must be within a specific +range+.
+    # Modifies expectation so that the number of invocations of the expected method must be within a specified range or exactly equal to a specified number.
     #
-    # @param [Range,Integer] range specifies the allowable range in the number of expected invocations.
+    # @param [Range,Integer] range_or_number specifies the allowable range for the number of expected invocations or the specified number of expected invocations.
     # @return [Expectation] the same expectation, thereby allowing invocations of other {Expectation} methods to be chained.
     #
-    # @example Specifying a specific number of expected invocations.
+    # @example Specifying an exact number of expected invocations.
     #   object = mock()
     #   object.expects(:expected_method).times(3)
     #   3.times { object.expected_method }
@@ -33,7 +34,7 @@ module Mocha
     #   2.times { object.expected_method }
     #   # => verify fails
     #
-    # @example Specifying a range in the number of expected invocations.
+    # @example Specifying a range for the number of expected invocations.
     #   object = mock()
     #   object.expects(:expected_method).times(2..4)
     #   3.times { object.expected_method }
@@ -43,12 +44,41 @@ module Mocha
     #   object.expects(:expected_method).times(2..4)
     #   object.expected_method
     #   # => verify fails
-    def times(range)
-      @cardinality.times(range)
+    def times(range_or_number)
+      @cardinality.times(range_or_number)
       self
     end
 
-    # Modifies expectation so that the expected method must be called exactly twice.
+    # Modifies expectation so that the expected method must be called exactly three times. This is equivalent to calling {#times} with an argument of +3+.
+    #
+    # @return [Expectation] the same expectation, thereby allowing invocations of other {Expectation} methods to be chained.
+    #
+    # @example Expected method must be invoked exactly three times.
+    #   object = mock()
+    #   object.expects(:expected_method).thrice
+    #   object.expected_method
+    #   object.expected_method
+    #   object.expected_method
+    #   # => verify succeeds
+    #
+    #   object = mock()
+    #   object.expects(:expected_method).thrice
+    #   object.expected_method
+    #   object.expected_method
+    #   object.expected_method
+    #   object.expected_method # => unexpected invocation
+    #
+    #   object = mock()
+    #   object.expects(:expected_method).thrice
+    #   object.expected_method
+    #   object.expected_method
+    #   # => verify fails
+    def thrice
+      @cardinality.exactly(3)
+      self
+    end
+
+    # Modifies expectation so that the expected method must be called exactly twice. This is equivalent to calling {#times} with an argument of +2+.
     #
     # @return [Expectation] the same expectation, thereby allowing invocations of other {Expectation} methods to be chained.
     #
@@ -74,7 +104,7 @@ module Mocha
       self
     end
 
-    # Modifies expectation so that the expected method must be called exactly once.
+    # Modifies expectation so that the expected method must be called exactly once. This is equivalent to calling {#times} with an argument of +1+.
     #
     # Note that this is the default behaviour for an expectation, but you may wish to use it for clarity/emphasis.
     #
@@ -136,7 +166,7 @@ module Mocha
       self
     end
 
-    # Modifies expectation so that the expected method must be called at least once.
+    # Modifies expectation so that the expected method must be called at least once. This is equivalent to calling {#at_least} with an argument of +1+.
     #
     # @return [Expectation] the same expectation, thereby allowing invocations of other {Expectation} methods to be chained.
     #
@@ -172,7 +202,7 @@ module Mocha
       self
     end
 
-    # Modifies expectation so that the expected method must be called at most once.
+    # Modifies expectation so that the expected method must be called at most once. This is equivalent to calling {#at_most} with an argument of +1+.
     #
     # @return [Expectation] the same expectation, thereby allowing invocations of other {Expectation} methods to be chained.
     #
@@ -200,9 +230,9 @@ module Mocha
     #
     # Positional arguments were separated from keyword arguments in Ruby v3 (see {https://www.ruby-lang.org/en/news/2019/12/12/separation-of-positional-and-keyword-arguments-in-ruby-3-0 this article}). In relation to this a new configuration option ({Configuration#strict_keyword_argument_matching=}) is available in Ruby >= 2.7.
     #
-    # When {Configuration#strict_keyword_argument_matching=} is set to +false+ (which is currently the default), a positional +Hash+ and a set of keyword arguments passed to {#with} are treated the same for the purposes of parameter matching. However, a deprecation warning will be displayed if a positional +Hash+ matches a set of keyword arguments or vice versa. This is because {Configuration#strict_keyword_argument_matching=} will default to +true+ in the future.
+    # When {Configuration#strict_keyword_argument_matching=} is set to +false+ (which is the default in Ruby v2.7), a positional +Hash+ and a set of keyword arguments passed to {#with} are treated the same for the purposes of parameter matching. However, a deprecation warning will be displayed if a positional +Hash+ matches a set of keyword arguments or vice versa.
     #
-    # When {Configuration#strict_keyword_argument_matching=} is set to +true+, an actual positional +Hash+ will not match an expected set of keyword arguments; and vice versa, an actual set of keyword arguments will not match an expected positional +Hash+, i.e. the parameter matching is stricter.
+    # When {Configuration#strict_keyword_argument_matching=} is set to +true+ (which is the default in Ruby >= v3.0), an actual positional +Hash+ will not match an expected set of keyword arguments; and vice versa, an actual set of keyword arguments will not match an expected positional +Hash+, i.e. the parameter matching is stricter.
     #
     # @see ParameterMatchers
     # @see Configuration#strict_keyword_argument_matching=
@@ -235,7 +265,11 @@ module Mocha
     #   object.expected_method(['string1'], 'any-old-value')
     #   # => verify fails
     #
-    # @example Loose keyword argument matching (default)
+    # @example Loose keyword argument matching (default in Ruby v2.7).
+    #
+    #   Mocha.configure do |c|
+    #     c.strict_keyword_argument_matching = false
+    #   end
     #
     #   class Example
     #     def foo(a, bar:); end
@@ -246,7 +280,7 @@ module Mocha
     #   example.foo('a', { bar: 'b' })
     #   # This passes the test, but would result in an ArgumentError in practice
     #
-    # @example Strict keyword argument matching
+    # @example Strict keyword argument matching (default in Ruby >= 3.0).
     #
     #   Mocha.configure do |c|
     #     c.strict_keyword_argument_matching = true
@@ -711,19 +745,19 @@ module Mocha
 
     # @private
     def mocha_inspect
-      message = "#{@cardinality.anticipated_times}, #{@cardinality.invoked_times}: #{method_signature}"
-      message << "; #{@ordering_constraints.map(&:mocha_inspect).join('; ')}" unless @ordering_constraints.empty?
+      strings = ["#{@cardinality.anticipated_times}, #{@cardinality.invoked_times}: #{method_signature}"]
+      strings << "; #{@ordering_constraints.map(&:mocha_inspect).join('; ')}" unless @ordering_constraints.empty?
       if Mocha.configuration.display_matching_invocations_on_failure?
-        message << @cardinality.actual_invocations
+        strings << @cardinality.actual_invocations
       end
-      message
+      strings.join
     end
 
     # @private
     def method_signature
-      signature = "#{@mock.mocha_inspect}.#{@method_matcher.mocha_inspect}#{@parameters_matcher.mocha_inspect}"
-      signature << " #{@block_matcher.mocha_inspect}" if @block_matcher.mocha_inspect
-      signature
+      strings = ["#{@mock.mocha_inspect}.#{@method_matcher.mocha_inspect}#{@parameters_matcher.mocha_inspect}"]
+      strings << " #{@block_matcher.mocha_inspect}" if @block_matcher.mocha_inspect
+      strings.join
     end
 
     # @private
