@@ -1,5 +1,6 @@
-require 'mocha/parameter_matchers/base'
-require 'mocha/parameter_matchers/deprecations'
+# frozen_string_literal: true
+
+require 'mocha/parameter_matchers/base_methods'
 
 module Mocha
   module ParameterMatchers
@@ -28,8 +29,6 @@ module Mocha
       end
     end
 
-    define_deprecated_matcher_method(:equals)
-
     # Parameter matcher which matches when actual parameter equals expected value.
     class Equals
       include BaseMethods
@@ -50,7 +49,5 @@ module Mocha
         @value.mocha_inspect
       end
     end
-
-    provide_deprecated_access_to(:Equals)
   end
 end
