@@ -1,5 +1,6 @@
-require 'mocha/parameter_matchers/base'
-require 'mocha/parameter_matchers/deprecations'
+# frozen_string_literal: true
+
+require 'mocha/parameter_matchers/base_methods'
 
 module Mocha
   module ParameterMatchers
@@ -24,13 +25,11 @@ module Mocha
       #   object.method_1('string')
       #   # error raised, because method_1 was not called with an Integer
       #
-      def is_a(klass) # rubocop:disable Naming/PredicateName
+      def is_a(klass) # rubocop:disable Naming/PredicatePrefix
         IsA.new(klass)
       end
     end
 
-    define_deprecated_matcher_method(:is_a)
-
     # Parameter matcher which matches when actual parameter is a specific class.
     class IsA
       include BaseMethods
@@ -51,7 +50,5 @@ module Mocha
         "is_a(#{@klass.mocha_inspect})"
       end
     end
-
-    provide_deprecated_access_to(:IsA)
   end
 end
