@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test/unit/testresult'
 
 class TestUnitResult
@@ -5,6 +7,8 @@ class TestUnitResult
     test_result = Test::Unit::TestResult.new
     class << test_result
       attr_reader :failures, :errors
+      attr_accessor :last_deprecation_warning
+
       def failure_messages
         failures.map(&:message)
       end
