@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require File.expand_path('../../test_helper', __FILE__)
 require 'mocha/expectation'
 require 'mocha/invocation'
@@ -192,7 +194,7 @@ class ExpectationTest < Mocha::TestCase
   end
 
   def test_should_raise_custom_exception
-    exception = Class.new(Exception)
+    exception = Class.new(StandardError)
     assert_raises(exception) { invoke(new_expectation.raises(exception)) }
   end
 
@@ -251,6 +253,30 @@ class ExpectationTest < Mocha::TestCase
     assert expectation.verified?
   end
 
+  def test_should_not_verify_successfully_if_call_expected_thrice_and_invoked_four_times
+    expectation = new_expectation.thrice
+    invoke(expectation)
+    invoke(expectation)
+    invoke(expectation)
+    invoke(expectation)
+    assert !expectation.verified?
+  end
+
+  def test_should_not_verify_successfully_if_call_expected_thrice_but_invoked_twice
+    expectation = new_expectation.thrice
+    invoke(expectation)
+    invoke(expectation)
+    assert !expectation.verified?
+  end
+
+  def test_should_verify_successfully_if_call_expected_thrice_and_invoked_thrice
+    expectation = new_expectation.thrice
+    invoke(expectation)
+    invoke(expectation)
+    invoke(expectation)
+    assert expectation.verified?
+  end
+
   def test_should_not_verify_successfully_if_call_expected_twice_and_invoked_three_times
     expectation = new_expectation.twice
     invoke(expectation)
@@ -338,7 +364,7 @@ class ExpectationTest < Mocha::TestCase
     sequence_two = Sequence.new('two')
     expectation = Expectation.new(mock, :expected_method).with(1, 2, { 'a' => true }, { b: false }, [1, 2, 3]).in_sequence(sequence_one, sequence_two)
     assert !expectation.verified?
-    assert_match %{mock.expected_method(1, 2, {"a" => true}, {:b => false}, [1, 2, 3]); in sequence "one"; in sequence "two"}, expectation.mocha_inspect
+    assert_match %{mock.expected_method(1, 2, {"a" => true}, {b: false}, [1, 2, 3]); in sequence "one"; in sequence "two"}, expectation.mocha_inspect
   end
 
   class FakeConstraint
